"use strict";

const util_1 = require("./util");
const path = require("path");
const bluebird_1 = require("bluebird");
const fse = require("fs-extra");
const awaiter_1 = require("./awaiter");
const __awaiter = awaiter_1.tsAwaiter;
Array.isArray(__awaiter);
const move = bluebird_1.Promise.promisify(fse.move);
const writeFile = bluebird_1.Promise.promisify(fse.outputFile);
const archToDebArch = {
    "x64": "amd64",
    "ia32": "i386"
};
function makeDeb(options, buildDir) {
    return __awaiter(this, void 0, void 0, function* () {
        if (!options.installPath.startsWith("/")) {
            throw new Error("installPath must be a valid absolute path: " + options.installPath);
        }
        const architecture = archToDebArch[options.architecture];
        const packageDir = path.join(path.dirname(buildDir), options.packageName + "-" + options.version + "-" + architecture);
        yield move(buildDir, path.join(packageDir, options.installPath), { clobber: true });
        yield writeDebianFiles(packageDir, Object.assign({
            architecture: "all",
            essential: "no",
            overwrite: true,
            priority: "optional",
            section: "main"
        }, options), architecture);
        yield util_1.exec("dpkg-deb", ["-b", packageDir]);
        return packageDir + ".deb";
    });
}
exports.makeDeb = makeDeb;
function writeDebianFiles(packageDir, options, architecture) {
    return writeFile(path.join(packageDir, "DEBIAN", "control"), `Package: ${ options.packageName }
Version: ${ options.version }
Section: ${ options.section }
Priority: ${ options.priority }
Architecture: ${ architecture }
Essential: ${ options.essential }
Maintainer: ${ options.maintainer }
Description: ${ options.packageDescription }
`);
}
//# sourceMappingURL=deb.js.map
